DeviceLocationExceptionReason enum
Identifies why a device-location operation could not be completed.
Values
- servicesDisabled → const DeviceLocationExceptionReason
-
The device's system location services are turned off or unavailable.
- permissionDenied → const DeviceLocationExceptionReason
-
The user denied foreground location permission for this request.
- permissionPermanentlyDenied → const DeviceLocationExceptionReason
-
The app cannot request foreground location access again.
Recovery can require a change in system settings or system policy.
- configurationMissing → const DeviceLocationExceptionReason
-
The host application is missing required platform permission setup.
- unsupportedPlatform → const DeviceLocationExceptionReason
-
The current operating system does not support device location.
-
A native location operation could not be completed.
-
The platform could not provide usable current coordinates.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DeviceLocationExceptionReason> - A constant List of the values in this enum, in order of their declaration.