MotionEffectTransform class final
Collects the visual operations applied by MotionEffect.apply.
Effects compose operations in declaration order. Effects must not retain an instance after MotionEffect.apply returns.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fade(
double opacity) → void -
Multiplies the current opacity by
opacity. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
double scale) → void - Applies a uniform scale after earlier operations.
-
toString(
) → String -
A string representation of this object.
inherited
-
translate(
{required double x, required double y}) → void - Applies a logical-pixel translation after earlier operations.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited